<div class="alert alert-block alert-error fade in" style="display: none;" id="delete_warning">
            <a class="close alert_close" href="#">×</a>
            <h4 class="alert-heading">Are you sure you want to delete this document?</h4>
            <p>Once you delete this document you can't recover it. It's gone forever!</p>
            <p>
                <a class="btn btn-success small alert_close" href="#">Cancel</a>
                <a class="btn btn-danger" id="action_delete_ok" href="#">Delete forever!</a> 
            </p>
</div>