{% extends "mongonaut/base.html" %}
{% load mongonaut_tags %}

{% block breadcrumbs %}
<li><a href="{% url index %}">Mongonaut</a> <span class="divider">/</span></li>
<li><a href="{% url document_list app_label document_name %}">{{ document_name }}s</a> <span class="divider">/</span></li>
<li><a href="{% url document_detail app_label document_name document.id %}">{{ document_name }}</a> <a href="{% url document_detail app_label document_name document.id %}">{{ document.id }}</a> <span class="divider">/</span></li>
<li><a href="">Delete</a>
{% endblock %}

{% block content %}

<h1>Are you sure you want to delete this {{ document_name }}?</h1>

<div class="row">
    <div class="span16">
        <form method="POST" action="">
            {% csrf_token %}
            <div class="actions">
                <a class="btn primary" href="{% url document_detail app_label document_name document.id %}">Wait, I change my mind!</a>&nbsp;
                <input type="submit" name="action_delete" class="btn danger"  value="Yes, delete this record.">&nbsp;
            </div>
        </form>        
    </div>
</div>    

{% endblock %}
